Changelog
==========

1.1.0 (2018-12-21)
-------------------

- Fix packaging

1.1.0 (2018-12-21)
-------------------

- Add a simple command-line client (petri)
- Debugging support, including message capture (petri)
- Fix breakage caused by refactoring (petri)
- Simple tests (petri)

1.0.0 (2018-12-18)
-------------------

- Improved packaging (petri)
- Modularize & refactor (petri)
- Better Python2 support (mleinart)

0.2 (2017-05-19)
-----------------

- First release @pypi (petri)
